import unittest

import src.hkkang_utils.list as list_utils


class Test_list_utils(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(Test_list_utils, self).__init__(*args, **kwargs)
    
    def test_do_flatten_list(self):
        pass


if __name__ == "__main__":
    unittest.main()
    
    